@@ -1,9 +1,9 @@
 # Detect product
 function blackdown_j2re_detect() {
   local found=
-  eval $(dpkg-architecture)
+  
   case "${DEB_BUILD_ARCH:-$DEB_BUILD_GNU_TYPE}" in
-    i386|i386-linux)
+    i386|i486-linux-gnu)
       case "$archive_name" in
 	"j2re-1.3.1-02b-FCS-linux-i386.bin") # SUPPORTED
 	    j2se_version=1.3.1+02a
@@ -71,7 +71,7 @@ function blackdown_j2re_detect() {
 	    ;;
       esac
       ;;
-    amd64|x86_64-linux)
+    amd64|x86_64-linux-gnu)
       case "$archive_name" in
 	"j2re-1.4.2-rc1-linux-amd64.bin") # SUPPORTED
 	    j2se_version=1.4.2+rc1
@@ -124,7 +124,7 @@ function blackdown_j2re_detect() {
 	cat << EOF
 
 Detected product:
-    Java(TM) Runtime Environment (J2RE)
+    Java(TM) Runtime Environment (JRE)
     Standard Edition, Version $j2se_version
     Blackdown Java-Linux
 EOF
@@ -133,7 +133,7 @@ EOF
 	    j2se_release="${j2se_version:0:3}"
 	    j2se_required_space=$(( $j2se_expected_min_size * 2 + 20 ))
 	    j2se_vendor="blackdown"
-	    j2se_title="Java(TM) 2 RE, Standard Edition, Blackdown"
+	    j2se_title="Java(TM) JRE, Standard Edition, Blackdown"
 	    j2re_run
 	fi
     fi
