@@ -32,7 +32,7 @@ function sun_j2sdk_doc_detect() {
 	cat << EOF
 
 Detected product:
-    Java(TM) Software Development Kit (J2SDK) Documentation
+    Java(TM) Development Kit (JDK) Documentation
     Standard Edition, Version $j2se_version
     Sun Microsystems(TM), Inc.
 EOF
@@ -41,7 +41,7 @@ EOF
 	    j2se_release="${j2se_version:0:3}"
 	    j2se_required_space=$(( $j2se_expected_min_size * 2 + 20 ))
 	    j2se_vendor="sun"
-	    j2se_title="Java(TM) 2 SDK, Standard Edition, Sun Microsystems(TM) Documentation"
+	    j2se_title="Java(TM) JDK, Standard Edition, Sun Microsystems(TM) Documentation"
 	    j2sdk_doc_run
 	fi
     fi
