@@ -1,9 +1,9 @@
 # Detect product
 function sun_j2sdk_detect() {
   local found=
-  eval $(dpkg-architecture)
+  
   case "${DEB_BUILD_ARCH:-$DEB_BUILD_GNU_TYPE}" in
-    i386|i386-linux)
+    i386|i486-linux-gnu)
       case "$archive_name" in
 	"j2sdk-1_4_1_"[0-9][0-9]"-linux-i586.bin") # SUPPORTED
 	    j2se_version="1.4.1+${archive_name:12:2}"
@@ -51,7 +51,7 @@ function sun_j2sdk_detect() {
 	    ;;
       esac
       ;;
-    amd64|x86_64-linux)
+    amd64|x86_64-linux-gnu)
       case "$archive_name" in
 	"jdk-1_5_0-beta2-linux-amd64.bin") # SUPPORTED
 	    j2se_version=1.5.0+beta2
@@ -75,7 +75,7 @@ function sun_j2sdk_detect() {
 	cat << EOF
 
 Detected product:
-    Java(TM) Software Development Kit (J2SDK)
+    Java(TM) Development Kit (JDK)
     Standard Edition, Version $j2se_version
     Sun Microsystems(TM), Inc.
 EOF
@@ -84,7 +84,7 @@ EOF
 	    j2se_release="${j2se_version:0:3}"
 	    j2se_required_space=$(( $j2se_expected_min_size * 2 + 20 ))
 	    j2se_vendor="sun"
-	    j2se_title="Java(TM) 2 SDK, Standard Edition, Sun Microsystems(TM)"
+	    j2se_title="Java(TM) JDK, Standard Edition, Sun Microsystems(TM)"
 	    j2sdk_run
 	fi
     fi
